
Lx = 1.92;
Ly = 0.06;
Lz = 0.03;
nx = 200;
dx = Lx/nx;
ny = ceil(Ly/dx);
nz = ceil(Lz/dx);

[Coord,Conec] = genmeshh8(Lx,Ly,Lz,nx,ny,nz);
Material = struct('Ley_Constitutiva','SaintVenant_Kirchhoff',...
    'Modulo_de_Young',1e7,'Coeficiente_de_Poisson',0.3);
[nele,nodxele] = size(Conec);
[nnod,dim] = size(Coord);
ndof = dim*nnod;
dofxele = dim*nodxele;
% Cargas
tolgeo = 0.001*dx;
Ptot = 20;
% Nodos con cargas
ncar = find(Coord(:,1)>Lx-tolgeo & Coord(:,2)>Ly-tolgeo);
cardof = dim*ncar-1;
Fext = zeros(ndof,1);
Fext(cardof) = 1;
Fext(cardof(1)) = 0.5;
Fext(cardof(end)) = 0.5;
Fext = Fext/sum(Fext)*Ptot;
% Fijaciones
% Nodos con fijaciones
nfij = find(Coord(:,1)<tolgeo);
fijdof = [dim*nfij-2; dim*nfij-1; dim*nfij];
libdof = setdiff(1:ndof,fijdof);

% Inicializacion de desplazamientos
U = zeros(ndof,1);
% Solucion iterativa de Newton-Raphson
tolNR = 1e-6*norm(Fext);
maxiter = 100;
VAL = zeros(nele,dofxele,dofxele);
ROW = zeros(nele,dofxele,dofxele);
COL = zeros(nele,dofxele,dofxele);
VALF = zeros(nele,dofxele);


for iter = 1:maxiter
    % Calculo de fuerzas internas y  matriz de rigidez tangente    
    parfor e = 1:nele
        conec = Conec(e,:);
        dof = zeros(1,dim*nodxele);
        dof(1:dim:end) = dim*conec-2;
        dof(2:dim:end) = dim*conec-1;
        dof(3:dim:end) = dim*conec;
        u = U(dof);
        coord = Coord(conec,:);
        [fint,k] = fuerza_y_matriz_elemental(u,coord,Material);
        VALF(e,:) = fint;
        VAL(e,:,:) = k;
        row = repmat(dof(:),1,dofxele);
        ROW(e,:,:) = row;
    end   
    COL = permute(ROW,[1 3 2]);
    K = sparse(ROW(:),COL(:),VAL(:),ndof,ndof);
    Fint = sparse(ROW(:,:,1),1,VALF,ndof,1);
    
    R = Fint-Fext;
    % Imposicion de fijaciones
    tic
%     K(:,fijdof) = [];
%     K(fijdof,:) = [];
    K = K(libdof,libdof);
    K = 0.5*(K+K');
    toc
    R = R(libdof);
    tic
    DeltaU = -K\R;
    toc
    U(libdof) = U(libdof)+DeltaU;
    if iter == 1
        U0 = U;
    end
    nres = norm(R)
    if nres < tolNR
        break;
    end
end